.. Canari Framework documentation master file, created by
   sphinx-quickstart on Sat Oct 10 15:22:29 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Canari Framework's documentation!
============================================

Contents:

.. toctree::
   :maxdepth: 4

   canari.quickstart
   canari.framework
   canari.maltego.message
   canari.config
   canari.mode
   canari.maltego.entities

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

